/*
 * Edite este ficheiro e copie o mesmo como userChrome.css para o seu
 * profile-directory/chrome/
 */

/*
 * Este ficheiro pode ser utilizado para personalizar a aparência do interface do utilizador do Mozilla
 * Deve considerar utilizar !important na regras que deseja ver
 * sobrepostas às pré-definições
 */

/*
 * Não remova a linha @namespace -- ela é requerida para o correcto funcionamento da aplicação
 */
@namespace url("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul"); /* define o namespace pré-definido para XUL */


/*
 * Alguns melhoramentos possíveis na acessibilidade:
 */
/*
 * Define o tamanho pré-definido de todos os tipos de letra para 20 pt:
 *
 * * {
 *   font-size: 20pt !important
 * }
 */
/*
 * Define os itens no menu em particular a 15 pt em vez do tamanho pré-definido:
 *
 * menupopup > * {
 *   font-size: 15pt !important
 * }
 */
/*
 * Dá à barra de endereços (URL) uma largura fixa para o tipo de letra
 *
 * #urlbar {
 *    font-family: monospace !important;
 * }
 */

/*
 * Elimina o 'throbber' e o seu movimento pertubador:
 *
 * #throbber-box {
 *   display: none !important;
 * }
 */

/*
 * Para mais exemplos visite http://www.mozilla.org/unix/customizing.html
 */

