/*
 * Edite este ficheiro e copie o mesmo como userContent.css para o seu
 * profile-directory/chrome/
 */

/*
 * Este ficheiro pode ser utilizado para aplicar um estilo a todas as páginas web que visualiza
 * Regras sem !important são sobrepostas pelas regras do autor se este
 * definiu alguma.  Regras com !important sobrepõe-se às regras do autor.
 */

/*
 * exemplo: desactivar o elemento "blink"
 *
 * blink { text-decoration: none ! important; }
 *
 */

/*
 * exemplo: dar a todas as tabelas uma borda com 2px
 *
 * table { border: 2px solid; }
 */

/*
 * exemplo: desactivar o elemento "marquee"
 *
 * marquee { -moz-binding: none; }
 *
 */

/*
 * Para mais exemplos visite http://www.mozilla.org/unix/customizing.html
 */

